==> chrome-devtools-kotlin-0.7.2-sources.jar: org/hildan/chrome/devtools/domains/emulation/EmulationTypes.kt <==
package org.hildan.chrome.devtools.domains.emulation

import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.collections.List
import kotlinx.serialization.Serializable
import org.hildan.chrome.devtools.protocol.ExperimentalChromeApi

/**
 * Screen orientation.
 *
 * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Emulation/#type-ScreenOrientation)
 */
@Serializable
public data class ScreenOrientation(
  /**
   * Orientation type.
   */
  public val type: String,
  /**
   * Orientation angle.
   */
  public val angle: Int
)

/**
 *
 *
 * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Emulation/#type-DisplayFeature)
 */
@Serializable
public data class DisplayFeature(
  /**
   * Orientation of a display feature in relation to screen
   */
  public val orientation: String,
  /**
   * The offset from the screen origin in either the x (for vertical
   * orientation) or y (for horizontal orientation) direction.
   */
  public val offset: Int,
  /**
   * A display feature may mask content such that it is not physically
   * displayed - this length along with the offset describes this area.
   * A display feature that only splits content will have a 0 mask_length.
   */
  public val maskLength: Int
)

/**
 *
 *
 * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Emulation/#type-MediaFeature)
 */
@Serializable
public data class MediaFeature(
  public val name: String,
  public val value: String
)

/**
 * advance: If the scheduler runs out of immediate work, the virtual time base may fast forward to
 * allow the next delayed task (if any) to run; pause: The virtual time base may not advance;
 * pauseIfNetworkFetchesPending: The virtual time base may not advance if there are any pending
 * resource fetches.
 *
 * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Emulation/#type-VirtualTimePolicy)
 */
@ExperimentalChromeApi
@Serializable
public enum class VirtualTimePolicy {
  advance,
  pause,
  pauseIfNetworkFetchesPending,
}

/**
 * Used to specify User Agent Cient Hints to emulate. See https://wicg.github.io/ua-client-hints
 *
 * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Emulation/#type-UserAgentBrandVersion)
 */
@ExperimentalChromeApi
@Serializable
public data class UserAgentBrandVersion(
  public val brand: String,
  public val version: String
)

/**
 * Used to specify User Agent Cient Hints to emulate. See https://wicg.github.io/ua-client-hints
 *
 * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Emulation/#type-UserAgentMetadata)
 */
@ExperimentalChromeApi
@Serializable
public data class UserAgentMetadata(
  public val brands: List<UserAgentBrandVersion>,
  public val fullVersion: String,
  public val platform: String,
  public val platformVersion: String,
  public val architecture: String,
  public val model: String,
  public val mobile: Boolean
)

/**
 * Enum of image types that can be disabled.
 *
 * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Emulation/#type-DisabledImageType)
 */
@ExperimentalChromeApi
@Serializable
public enum class DisabledImageType {
  avif,
  webp,
}

==> chrome-devtools-kotlin-0.13.1-sources.jar: org/hildan/chrome/devtools/domains/emulation/EmulationTypes.kt <==
@file:Suppress("RedundantVisibilityModifier", "DEPRECATION", "EXPERIMENTAL_API_USAGE")

package org.hildan.chrome.devtools.domains.emulation

import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlinx.serialization.Serializable
import org.hildan.chrome.devtools.protocol.ExperimentalChromeApi

/**
 * Screen orientation.
 *
 * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Emulation/#type-ScreenOrientation)
 */
@Serializable
public data class ScreenOrientation(
  /**
   * Orientation type.
   */
  public val type: String,
  /**
   * Orientation angle.
   */
  public val angle: Int
)

/**
 *
 *
 * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Emulation/#type-DisplayFeature)
 */
@Serializable
public data class DisplayFeature(
  /**
   * Orientation of a display feature in relation to screen
   */
  public val orientation: String,
  /**
   * The offset from the screen origin in either the x (for vertical
   * orientation) or y (for horizontal orientation) direction.
   */
  public val offset: Int,
  /**
   * A display feature may mask content such that it is not physically
   * displayed - this length along with the offset describes this area.
   * A display feature that only splits content will have a 0 mask_length.
   */
  public val maskLength: Int
)

/**
 *
 *
 * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Emulation/#type-MediaFeature)
 */
@Serializable
public data class MediaFeature(
  public val name: String,
  public val value: String
)

/**
 * advance: If the scheduler runs out of immediate work, the virtual time base may fast forward to
 * allow the next delayed task (if any) to run; pause: The virtual time base may not advance;
 * pauseIfNetworkFetchesPending: The virtual time base may not advance if there are any pending
 * resource fetches.
 *
 * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Emulation/#type-VirtualTimePolicy)
 */
@ExperimentalChromeApi
@Serializable
public enum class VirtualTimePolicy {
  advance,
  pause,
  pauseIfNetworkFetchesPending,
}

/**
 * Used to specify User Agent Cient Hints to emulate. See https://wicg.github.io/ua-client-hints
 *
 * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Emulation/#type-UserAgentBrandVersion)
 */
@ExperimentalChromeApi
@Serializable
public data class UserAgentBrandVersion(
  public val brand: String,
  public val version: String
)

/**
 * Used to specify User Agent Cient Hints to emulate. See https://wicg.github.io/ua-client-hints
 * Missing optional values will be filled in by the target with what it would normally use.
 *
 * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Emulation/#type-UserAgentMetadata)
 */
@ExperimentalChromeApi
@Serializable
public data class UserAgentMetadata(
  public val brands: List<UserAgentBrandVersion>? = null,
  public val fullVersion: String? = null,
  public val platform: String,
  public val platformVersion: String,
  public val architecture: String,
  public val model: String,
  public val mobile: Boolean
)

/**
 * Enum of image types that can be disabled.
 *
 * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Emulation/#type-DisabledImageType)
 */
@ExperimentalChromeApi
@Serializable
public enum class DisabledImageType {
  avif,
  webp,
}
